@@ -21,4 +21,12 @@ class RoyaltyWorkflowsClient:
         with open(abi_path, 'r') as abi_file:
             abi = json.load(abi_file)
         self.contract = self.web3.eth.contract(address=contract_address, abi=abi)
+    
+    def claimAllRevenue(self, ancestorIpId, claimer, childIpIds, royaltyPolicies, currencyTokens):
+        
+        return self.contract.functions.claimAllRevenue(ancestorIpId, claimer, childIpIds, royaltyPolicies, currencyTokens).transact()
+        
+    def build_claimAllRevenue_transaction(self, ancestorIpId, claimer, childIpIds, royaltyPolicies, currencyTokens, tx_params):
+        return self.contract.functions.claimAllRevenue(ancestorIpId, claimer, childIpIds, royaltyPolicies, currencyTokens).build_transaction(tx_params)
+    
     
\ No newline at end of file
